function ier = bwavescdep(xh,hh,x)

% Calculate depth and its derivative for use with bwavesc
% call as
%       ier = bwavescdep(xh,hh,x)
%   where
%       xh,hh  (cm,cm)  = arrays of input x and depth
%       x (cm)          = x array for depth
%       ier             = error code (0 or 1)

%   K. Brink  2/25/2020  3/18/2020

global h hx icbc iobc

ier = 0;
dx = x(2) - x(1);
xmax = max(x);


%   Do quality control

ii = find(hh) < 0;
if isempty(ii) ~= 0
    disp(' ')
    disp('Error: must have depth > 0!')
    disp(' ')
end

if xh(1) > 0
    xh = [0 xh];
    hzero = hh(1);
    hh = [hzero hh];
end

if max(xh) < xmax
    xh = [xh xmax];
    hh = [hh hh(end)];

end
    
    

h = interp1(xh,hh,x,'linear');

hx = NaN*h;
hx(end) = (h(end)-h(end-1))/dx;
hx(1)=  (h(2)-h(1))/dx;
hx(2:end-1) = 0.5*(h(3:end) - h(1:end-2))/dx;

hxer = 1e-10;
if icbc == 1 && abs(hx(1)) > hxer
    disp(' ') 
    disp('Error: Must have h_x = 0 at x = 0 if there is an open boundary condition there!')
    disp(' ')
    ier = 1;
end
if iobc == 1 && abs(hx(end))> hxer
    disp(' ') 
    disp('Error: Must have h_x = 0 at x = x_Max if there is an open boundary condition there!')
    disp(' ')
    ier = 1;
end

