function finm = bwavescfinch(fin)

%   M file to modify an existing input file conveniently
%   For use with bwavesc: Complex frequency
%   Call as
%       finm = bwavescfinch(fin)
%   where
%       fin          = old  array for input to bwavesc
%       finm         = new array for bwavesc input

%   8/26/2003, 1/1/2005, 3/30/2012  3/16/2020

disp(' ')
x = ['First you need to select what you want to change.'
     '                                                 '
     '     Options are:                                '
     '       Grid size: enter "g"                      '
     '       Initial Frequency guess: w                '
     '       Coriolis parameter: f                     '
     '       Domain size:  x                           '
     '       Model assumptions:  a                     '
     '       Dispersion curve definition:   d          '
     '       Nominal accuracy: e                       '
     '       Depth profile: h                          '
     '       Bottom friction:  r                       '       
     '       Mean flow field:   v                      '
     '                                                 '
     'Any arrays are row arrays, not column arrays     '
     '                                                 '];
 disp(x)

finm = fin;
[ni,mi] = size(fin);
ni = max(ni,mi);

stin = input('Select an option ','s');
disp(' ')   

if stin == 'g'
    disp(['Old nn = ' int2str(fin(1))])
    arr = input(' Enter new nn ');
    finm(1) = arr;
    
elseif stin == 'w'
    disp(['Old real part of frequency guess (sec^-1) '  num2str(fin(11))])
    arr = input('Enter new real part of frequency   (sec^-1) ');
    finm(11) = arr;
    disp(['Old imaginary part of frequency guess (sec^-1) '  num2str(fin(12))])
    arr = input('Enter new imaginary part of frequency   (sec^-1) ');
    finm(12) = arr;
    
elseif stin == 'a'
    disp('Old model assumptions')
    if fin(4) == 0
        disp('Rigid lid')
    else
        disp('Free surface')
    end
       
    ar1 = input('Enter 0 for rigid lid, 1 for free surface ');
    finm(4) = ar1;
    disp(' ')
    if fin(5) < 0.5
        disp('Closed boundary at x = 0')
    else
        disp('Open boundary at x = 0')
    end
    if fin(6) < 0.5
        disp('Closed boundary at x = x_Max')
    else
        disp('Open boundary at x = x_Max')
    end
    
    icbc = input('Enter 0 for a closed boundary at x = 0, 1 for an open boundary ');
    iobc = input('Enter 0 for a closed boundary at x = x_Max, 1 for an open boundary ');
    finm(5) = icbc;
    finm(6) = iobc;
    
elseif stin == 'f'
    disp(['Old Coriolis parameter = ' num2str(fin(7))])
    finm(7) = input('Enter new Coriolis parameter  (sec^-1) ');
    
elseif stin == 'e'
    disp(['Old nominal fractional accuracy = ' num2str(fin(3))])
    finm(3) = input('Enter new nominal fractional accuracy ');
    
elseif stin == 'd'
    disp(['Previous number of dispersion curve points = ' int2str(fin(8))])
    finm(8) = input('Enter number of points on the dispersion curve ');
    disp(['Old first wavenumber, increment along curve (cm^-1) = ' num2str(fin(9:10))])
    finm(9) = input('Enter new first alongshore wavelength (cm-1) ');
    if finm(8) <= 1.2
        finm(10) = fin(9);
    else
        finm(10) = input('Enter new wavenumber increment (cm-1) ');
    end
    
elseif stin == 'x'
    disp(['Old offshore domain width (km) = ' num2str(fin(2))])
    finm(2) = input('Enter new domain size (km) ');
    
elseif stin == 'h'
    ndi = fin(13);
    disp(['Old number of depth input points = ' int2str(ndi)])
    nd = input('Enter number of (x,h) pairs (km, m) (> 0) ');
    if ndi < 1
        disp('Error!! nd must be >= 1')
    end
    finm(13) = nd;
    finfr = fin((14+2*ndi):end);
    disp(['Old array of x locations for depth (km) = ' num2str(fin(14:(13+ndi)))])
    ar1 = input('Enter array of x locations where depth will be given (km) ');
    
    disp(['Old array of depths (m) = ' num2str(fin((14+ndi):13+2*ndi))])
    ar2 = input('Enter array of depths at locations given (m) ');
    finm(14:(13+nd)) = ar1;
    finm((14+nd):(13+2*nd)) = ar2;
    finm = [finm(1:(13+2*nd)) finfr];
    
    
elseif  stin == 'r'
    nd = fin(13);
    nlowv = 14 + 2*nd;           % location of nv
    nv = fin(nlowv);
    nlowr = nlowv + 2*nv +1;
    nri = fin(nlowr);
    disp(['Old number of r values = ' int2str(nri)])
    nr = input('Enter number of (x,r) pairs (>=0) ');
    finm(nlowr) = nr;
    nhigh = nlowr + 2*nr;
    
    finm  = finm(1:nlowr); 
    if nr ~=0
        if nri ~= 0
            disp(['Old r locations = ' num2str(fin(nlowr+1:nlowr + nri))])
        end
        ar1 = input('Enter array of x locations where resistance coefficient is given (km) ');
        if ar1(1) ~= 0
            disp(' ')
            disp('Error!! First location must be x = 0')
            disp(' ')
        end
        if nri ~= 0
            disp(['Old r values = ' num2str(fin(nlowr+1+nri:nlowr+2*nri))])
        end
        ar2 = input('Enter array of resistance coefficient (cm/sec) ');
        %finm((nlowr+1):(nlowr+nr)) = ar1;
        %finm((nlowr+1+nr):(nlowr + 2*nr)) = ar2;
        finm = [finm ar1 ar2];
      
    end
    
    
elseif stin == 'v'
    ndi = fin(13);
    nlowv = 14 + 2*ndi;              % location of nv
    
    nvi = fin(nlowv);
    disp(['Old number of x, vbar pairs (nv) = ' num2str(nvi)])
    nv = input('Enter new number of x, vbar pairs (nv) ');
    
    finfr = fin((nlowv + 1 +2*nvi):end);
    if nv == 0
        finm = fin(1:nlowv-1);
        finm = [finm 0 finfr] ;      
        
    else
        finm(nlowv) = nvi;
        xvi = fin(nlowv+1:nlowv + nvi);
        vbi = fin(nlowv+nvi+1:nlowv+2*nvi);
        disp(['Old xv locations = ' num2str(xvi)])
        xv = input('Enter array of vbar locations (xv) ');
        
        if length(xv) ~= nv
            disp(' ')
            disp('Error: array length should equal new nv')
            disp(' ')
        end
        disp(['Old vbar values = ' num2str(vbi)])
        vb = input('Enter new array of mean velocity (vbar) ');
        
        if length(vb) ~= nv
            disp(' ')
            disp('Error: array length should equal new nv')
            disp(' ')
            
        end
        
        
        finm(nlowv) = nv;
        finm(nlowv +1: nlowv+nv) = xv;
        finm(nlowv + 1 + nv:nlowv +2*nv) = vb;
    
        finm = [finm(1:nlowv+2*nv) finfr];
    end
    
    
    

else
    disp('Value entered does not correspond to any of the above categories')
end


%       Check on array length
    nd = finm(13);
    nlowv = 14 + 2*nd;
    nv = finm(nlowv);
    nlowr = nlowv + 2*nv +1;
    
    nr = finm(nlowr);
   
    ncheck = 13 + 2*nd + 1 + 2*nv + 1 + 2*nr;
    if length(finm) ~= ncheck
        disp(' ')
        disp('Problem! length is not right!')
        disp(' ')
    end
