function ier = bwavescr(xrr,rr,x,str)

%   Fill in bottom friction parameter AND plot r,vbar, h
%   For use with bwavesc.m
%   Call as
%       ier = bwavescr(xrr,rr,x)
%   where
%       xrr  (cm)       = array of r locations read in
%       rr   (cm/sec)   = array of r values
%       x    (cm)       = array of gridded x values
%       str (string)    = run name
%       ier             = an error flag

%   K. Brink  3/10/2020  3/18/2020

global r rx h v dx icbc iobc


ier = 0;
r = 0*x;
rx = r;

if isempty(rr) == 0
    xmax = x(end);
    if xrr(1) > 0;
        xrr = [0 xrr];
        rr = [rr(1) rr];
    end
    
    if xrr(end) < xmax
        xrr = [xrr xmax];
        rr = [rr rr(end)];
    end
    
    r = interp1(xrr,rr,x,'linear');
    
    rx(1) = (r(2) - r(1))/dx;
    rx(end) = (r(end) - r(end-1))/dx;
    rx(2:end-1) = 0.5*(r(3:end) - r(1:end-2))/dx;

end

rt = abs(rx(1));
if rt > 1e-12 && icbc > 0.5
    disp(' ')
    disp('Error: r_x must be zero at x = 0 if there is an open boundary there!')
    disp(' ')
    ier = 1;
end

rt = abs(rx(end));
if rt > 1e-12 %% iobc > 0.5
    disp(' ')
    disp('Error: r_x must be zero at x = x_Max if there is an open boundary there!')
    disp(' ')
    ier = 1;
end

%   Plot out basic fields
figure(2)
clf
xp = x*1e-5;

hmax = max(h)/100;
xmax = max(x)/1e5;

xf = [0 x 0]/1e5;
yf = [-hmax -h/100 -hmax];

if sum(rr) > 1e-10
    subplot(3,1,1)
    
    rmax = max(rr);
    plot(xp,r,'k')
else
    subplot(3,1,1)
    rmax = 0.7;
    plot(xp,0*x)
    hold on
        text(xmax/2,0.5,'r = 0')
    hold off
end


axis([0 xmax 0 1.5*rmax])  
title(['Bottom friction parameter [cm/sec] for run ' str])
ylabel('r [cm/sec]')

subplot(3,1,2)

if sum(v.*v)> 1e-6
    plot(xp,v,'k',xp,0*xp,'k')
    vmax = max(v);
    vmin = min(v);
   
else
    vmin = 0;
    vmax = 1;
    plot(xmax*[0 0 1],[1 0 0],'k')
    hold on
        text(0.5*xmax,0.5*vmax,'vbar = 0')
    hold off
end
axis([0 xmax 1.3*vmin 1.3*vmax]);
title('Mean Velocity [cm/sec]')
ylabel('v [cm/sec]')

subplot(3,1,3)
zmax = max(h)/100;


fill(xf,yf,0.9*[1 1 1])

axis([0 xmax -zmax 0])
title('Depth')
ylabel('Depth [m]')
xlabel('Offshore distance [km]')
set(gca,'TickDir','out')

