function pp = bwavescsol(w)

%   Solve for pressure, given a complex omega
%   For use with bwavesc.m
%      
%   call as
%       pp = bwavescsol(w)
%   where
%       pp (arbitrary units)    = pressure
%       w  (1/sec)              = complex frequency

%   K. Brink 2/25/2020  3/10/2020 3/16/2020  3/18/2020

global f h hx rl ncal del dx g v vx vxx icbc iobc r rx


nx = length(hx);
x = dx*(0:(nx-1));
rlc = rl(ncal);
fp = f + vx;
wpp = w + rlc*v;
wp = wpp -1i*r./h;
rhx = rx./h - r.*hx./(h.*h);
wpx = rlc*vx -1i*rhx;


fw = f*fp - wp.*wp;
fwx = f*vxx - 2.0*wp.*wpx;
dx2 = 2*dx;
dxx = dx*dx;

A1 = h.*fw;
A2 = hx.*fw  -1i*h.*rhx.*fw./wp - h.*fwx;
%A3 = -rlc*rlc*h - del*fw/g + f*rlc*hx/w;
A3 = -del*wpp.*fw.*fw./(g.*wp) + f*rlc*hx.*fw./wp - f*rlc*h.*fwx./wp;
A3 = A3 -rlc*rlc*h.*fw;

AA = 0*ones(nx,3);
BB = 0*ones(nx,1);
nf = round(nx/2);
%nf = round(nx/10);
BB(nf)  =   1;

ap = A1/dxx + A2/dx2;
ad = -2*A1/dxx + A3;
am = A1/dxx - A2/dx2;

AA(:,1) = am.';
AA(:,2) = ad.';
AA(:,3) = ap.';

%  x = 0 boundary condition
    AA(1,3) = AA(1,3) + AA(1,1);
    con = dx2*f*rlc/wp(1);
    betc = sqrt(del*fw(1)/(g*h(1)) + rlc*rlc);
    if real(betc < 0)
        betc = -betc;
    end
    con2 = dx2*betc;
    AA(1,2) = AA(1,2) + AA(1,1)*(con*(1-icbc) -con2*icbc);
    AA(1,1) = 0;

%   x = W boundary condition
    beto = sqrt(-A3(end)/A1(end));
    if real(beto < 0)
        beto = -beto;
    end
    con2 = dx2*beto;
    con = dx2*f*rlc/wp(end);
    AA(end,1) = AA(end,1) + AA(end,3);
    AA(end,2) = AA(end,2) -con2*AA(end,3)*iobc -(1-iobc)*con*AA(end,3);
    AA(end,3) = 0;

%   solve for pressure

pp = NaN*h;
for ix = 1:nx-1
    rat = AA(ix+1,1)/AA(ix,2);
    AA(ix+1,2) = AA(ix+1,2) -rat*AA(ix,3);
    BB(ix+1) = BB(ix+1) - BB(ix)*rat;
    %AA(ix+1,1) = 0;
end
pp(end) = BB(end)/AA(end,2);

for ix = (nx-1):-1:1
    BB(ix) = BB(ix) - AA(ix,3)*pp(ix+1);
    pp(ix) = BB(ix)/AA(ix,2);
end

