function ier = bwavescvel(xvv,vbarv,x)

%   Fill in mean alongshore flow and derivatives for use with bwavesc
%   call as
%       ier = bwavescvel(xvv,vbarv,x)
%   where
%       xvv (cm)        = x values read in
%       vbarv (cm/sec)  = vbar values read in
%       x (cm)          = model x grid points
%       ier             = an error code

%   K. Brink  3/10/2020 3/14/2020 3/16/2020 3/18/2020

global f v vx vxx h hx icbc iobc

ier = 0;
v = 0*x;
vx = v;
vxx = v;

nv = length(vbarv);

if isempty(vbarv) == 0 
    dx = x(2) - x(1);
    dxx = dx*dx;
    
    if xvv(1) > 1e-10
        xvv = [0 xvv];
        vbarv = [vbarv(1) vbarv];
        nv = nv + 1;
    end
        
    if xvv < x(end)
        xvv = [xvv x(end)];
        vbarv = [vbarv vbarv(end)];
    end
       
    
    v = interp1(xvv,vbarv,x,'linear');
    
    vx(1) = (v(2)-v(1))/dx;
    vx(end) = 0;
    vx(2:end-1) = 0.5*(v(3:end) - v(1:end-2))/dx;
   
    
    vxx(1) = 0;
    vxx(end) = 0;
    vxx(2:end-1) = (v(3:end) - 2*v(2:end-1) + v(3:end))/dxx;
    
    t1 = f + vx;
    t11 = max(t1);
    t12 = min(t1);
    if (t11/t12) < 0
        disp(' ')
        disp('         (f + v_x) changes sign!')
        disp(' ')
        
        figure(62)
        plot(x*1e-5,t1,'k', x*1e-5,0*x,'k')
        xlabel('x [km]')
        ylabel('[1/sec]')
        title('f + v_x')
    end
    
    t2 = vxx./h -(f+vx).*hx./(h.*h);
    t21 = max(t2);
    t22 = min(t2);
    if (t21/t22) < 0
        disp(' ')
        disp('    Potentially barotropically unstable!')
        disp('          ((f + v_x)/h)_x changes sign')
        disp(' ')
        
        figure(61)
        plot(x*1e-5,t2,'k', x*1e-5,0*x,'k')
        xlabel('x [km]')
        ylabel('[1/(sec cm^2)]')
        title('Gradient of [(f + v_x)/h]')
    end
end
        
    
 vxer = 1e-10;
if icbc == 1 && abs(vx(1)) > vxer
    disp(' ') 
    disp('Error: Must have v_x = 0 at x = 0 if there is an open boundary condition there!')
    disp(' ')
    ier = 1;
end
if iobc == 1 && abs(vx(end))> vxer
    disp(' ') 
    disp('Error: Must have v_x = 0 at x = x_Max if there is an open boundary condition there!')
    disp(' ')
    ier = 1;
end   
    